@@ -33,7 +33,6 @@
 #  define KIDLETIME_DECL_DEPRECATED_NO_EXPORT KIDLETIME_NO_EXPORT KIDLETIME_DECL_DEPRECATED
 #endif
 
-/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef KIDLETIME_NO_DEPRECATED
 #    define KIDLETIME_NO_DEPRECATED
@@ -42,6 +41,8 @@
 
 #define KIDLETIME_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KIDLETIME_NO_DEPRECATED) && !defined(KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -85,7 +86,7 @@
 #define KIDLETIME_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIDLETIME_NO_DEPRECATED
-#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
+#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54e00
 #endif
 #ifdef KIDLETIME_NO_DEPRECATED_WARNINGS
 #  define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0
@@ -95,7 +96,7 @@
 #  ifdef KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIDLETIME_DEPRECATED_WARNINGS_SINCE KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x57400
+#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x54e00
 #  endif
 #endif
 
@@ -104,7 +105,7 @@
 #endif
 
 #ifdef KIDLETIME_DEPRECATED
-#  define KIDLETIME_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KIDLETIME_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KIDLETIME_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -117,12 +118,5 @@
 #define KIDLETIME_DEPRECATED_VERSION_5(minor, text)      KIDLETIME_DEPRECATED_VERSION_5_##minor(text)
 #define KIDLETIME_DEPRECATED_VERSION(major, minor, text) KIDLETIME_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KIDLETIME_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIDLETIME_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KIDLETIME_DEPRECATED_VERSION(major, minor, text)
-#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIDLETIME_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KIDLETIME_EXPORT_H */
